        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>22</strong> miembros: 27 <br>3,5,8,9,10,11,13,14,16,18,19,20,21,22,24,27,30,31,32,33,34,36,39,42,44,46,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 24 <strong>control</strong><br>0,1,2,4,6,7,12,15,17,23,25,26,28,29,35,37,38,40,41,43,45,47,48,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>22</strong> miembros: 27 <br>3,5,8,9,10,11,13,14,16,18,19,20,21,22,24,27,30,31,32,33,34,36,39,42,44,46,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 24 <strong>control</strong><br>0,1,2,4,6,7,12,15,17,23,25,26,28,29,35,37,38,40,41,43,45,47,48,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>22</strong> miembros: 27 <br>3,5,8,9,10,11,13,14,16,18,19,20,21,22,24,27,30,31,32,33,34,36,39,42,44,46,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 24 <strong>control</strong><br>0,1,2,4,6,7,12,15,17,23,25,26,28,29,35,37,38,40,41,43,45,47,48,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>22</strong> miembros: 27 <br>3,5,8,9,10,11,13,14,16,18,19,20,21,22,24,27,30,31,32,33,34,36,39,42,44,46,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 24 <strong>control</strong><br>0,1,2,4,6,7,12,15,17,23,25,26,28,29,35,37,38,40,41,43,45,47,48,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>22</strong> miembros: 27 <br>3,5,8,9,10,11,13,14,16,18,19,20,21,22,24,27,30,31,32,33,34,36,39,42,44,46,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260718 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 24 <strong>control</strong><br>0,1,2,4,6,7,12,15,17,23,25,26,28,29,35,37,38,40,41,43,45,47,48,49';}
}
